# Copyright (c) 2022 Webezy.io.

# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:

# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

"""Init script for webezy.io template PubSubTs
Generated thanks to -

                 _                           _        
 __      __ ___ | |__    ___  ____ _   _    (_)  ___  
 \ \ /\ / // _ \| '_ \  / _ \|_  /| | | |   | | / _ \ 
  \ V  V /|  __/| |_) ||  __/ / / | |_| | _ | || (_) |
   \_/\_/  \___||_.__/  \___|/___| \__, |(_)|_| \___/ 
                                   |___/              



Author: Amit Shmulevitch
"""
# Main webezyio class to create gRPC services programmatically
# (Same inteface that webezyio cli is built as wrapper for
# WebezyArchitect whenever you generate new resource / create new project)
from webezyio.architect import WebezyArchitect

# Some common utils modules to help us build the services faster
# and adds an validations to object before they created
from webezyio.commons import helpers, file_system

# Webezy proto modules also helps us here to construct our services
# gRPC used to create another gRPC ! :)
from webezyio.commons.protos.webezy_pb2 import Language, WebezyContext, WebezyFileContext

# Default system imports
import os
import sys
import argparse
import zlib

    
"""Initialize constants and WebezyArchitect class"""
parser = argparse.ArgumentParser(
                    prog = 'PubSubTs',
                    description = 'What the program does',
                    epilog = 'Text at the bottom of help')
parser.add_argument('--domain',default='webezy')           # optional argument
parser.add_argument('--project-name',default='PubSubTs')           # optional argument

args = parser.parse_args()

# Constants
_PATH = file_system.join_path(os.getcwd(), 'webezy.json') 
_DOMAIN = args.domain
_PROJECT_NAME = args.project_name
_SERVER_LANGUAGE = Language.Name(Language.typescript)
_HOST = 'localhost'
_PORT = 50051

# Initializing WebezyArchitect class which we going to interact with
# It is used to create all of our 'webezyio' resources
_architect = WebezyArchitect(path=_PATH,
                             domain=_DOMAIN,
                             project_name=_PROJECT_NAME)
_architect.SetConfig({'host': _HOST, 'port': _PORT})
_architect.SetDomain(_DOMAIN)
    
"""Project specific configurations"""
    
# Init all the client to be used with your services
# Here we configured a python + typescript clients to be created with our services    
_clients = [{'language': 'python', 'out_dir': file_system.join_path(_PATH, 'clients', Language.Name(Language.python))}, {'language': 'typescript', 'out_dir': file_system.join_path(_PATH, 'clients', Language.Name(Language.typescript))}]
    
# Adding the base project data
_project = _architect.AddProject(server_language=_SERVER_LANGUAGE,
                                 clients=_clients)

# NOTE - that every call to WebezyArchitect executions
# it will return the proto generated class of that object
# which can be used to enrich the webezy base structure
# or debug easly whats going on beneath the surface
# print(type(_project))
# <class 'webezy_pb2.Project'>

    
# Creating enums values

        
# Creating enums   
 
        
"""Packages and thier resources"""
# Construct fields    

# Constructing a field for [webezy_PubSubPackage_v1_ConsumeTopic_topic]
_field_webezy_PubSubPackage_v1_ConsumeTopic_topic = helpers.WZField(name='topic',
                              description='This is the topic id to consume from',
                              label='LABEL_OPTIONAL',
                              type='TYPE_STRING',
                              message_type=None,
                              enum_type=None)

# Constructing a field for [webezy_PubSubPackage_v1_ConsumeTopic_topics]
_field_webezy_PubSubPackage_v1_ConsumeTopic_topics = helpers.WZField(name='topics',
                              description='',
                              label='LABEL_REPEATED',
                              type='TYPE_STRING',
                              message_type=None,
                              enum_type=None)

# Constructing a field for [webezy_PubSubPackage_v1_PublishEvent_timestamp]
_field_webezy_PubSubPackage_v1_PublishEvent_timestamp = helpers.WZField(name='timestamp',
                              description='The time event has been triggered',
                              label='LABEL_OPTIONAL',
                              type='TYPE_MESSAGE',
                              message_type='google.protobuf.Timestamp',
                              enum_type=None)

# Constructing a field for [webezy_PubSubPackage_v1_PublishEvent_topic]
_field_webezy_PubSubPackage_v1_PublishEvent_topic = helpers.WZField(name='topic',
                              description='A topic to publish the event',
                              label='LABEL_OPTIONAL',
                              type='TYPE_STRING',
                              message_type=None,
                              enum_type=None)

# Constructing a field for [webezy_PubSubPackage_v1_PublishEvent_event]
_field_webezy_PubSubPackage_v1_PublishEvent_event = helpers.WZField(name='event',
                              description='The event data',
                              label='LABEL_OPTIONAL',
                              type='TYPE_MESSAGE',
                              message_type='google.protobuf.Struct',
                              enum_type=None)

# Constructing a field for [webezy_PubSubPackage_v1_Topic_name]
_field_webezy_PubSubPackage_v1_Topic_name = helpers.WZField(name='name',
                              description='The topic name (Must be unique - See list of active topics with ListTopic RPC)',
                              label='LABEL_OPTIONAL',
                              type='TYPE_STRING',
                              message_type=None,
                              enum_type=None)

# Constructing a field for [webezy_PubSubPackage_v1_CreateTopicResponse_status]
_field_webezy_PubSubPackage_v1_CreateTopicResponse_status = helpers.WZField(name='status',
                              description='A human readable status of process',
                              label='LABEL_OPTIONAL',
                              type='TYPE_STRING',
                              message_type=None,
                              enum_type=None)

# Constructing a field for [webezy_PubSubPackage_v1_PublishEventResponse_status]
_field_webezy_PubSubPackage_v1_PublishEventResponse_status = helpers.WZField(name='status',
                              description='A human readable status of process',
                              label='LABEL_OPTIONAL',
                              type='TYPE_STRING',
                              message_type=None,
                              enum_type=None)

# Constructing a field for [webezy_PubSubPackage_v1_DropTopicResponse_topic]
_field_webezy_PubSubPackage_v1_DropTopicResponse_topic = helpers.WZField(name='topic',
                              description='The topic unique name to be dropped from queue',
                              label='LABEL_OPTIONAL',
                              type='TYPE_STRING',
                              message_type=None,
                              enum_type=None)

# Constructing a field for [webezy_PubSubPackage_v1_DropTopicRequest_topic]
_field_webezy_PubSubPackage_v1_DropTopicRequest_topic = helpers.WZField(name='topic',
                              description='The topic which we want to drop',
                              label='LABEL_OPTIONAL',
                              type='TYPE_MESSAGE',
                              message_type=_DOMAIN + '.PubSubPackage.v1.Topic',
                              enum_type=None)

# Constructing a field for [webezy_PubSubPackage_v1_DropTopicRequest_force]
_field_webezy_PubSubPackage_v1_DropTopicRequest_force = helpers.WZField(name='force',
                              description='If true it will drop the connection even if there are live consumers for the same topic, else it will fail the drop process',
                              label='LABEL_OPTIONAL',
                              type='TYPE_BOOL',
                              message_type=None,
                              enum_type=None)

# Packing all fields for [webezy_PubSubPackage_v1_ConsumeTopic]
_msg_fields_webezy_PubSubPackage_v1_ConsumeTopic = [_field_webezy_PubSubPackage_v1_ConsumeTopic_topic,_field_webezy_PubSubPackage_v1_ConsumeTopic_topics]
# Packing all fields for [webezy_PubSubPackage_v1_PublishEvent]
_msg_fields_webezy_PubSubPackage_v1_PublishEvent = [_field_webezy_PubSubPackage_v1_PublishEvent_timestamp,_field_webezy_PubSubPackage_v1_PublishEvent_topic,_field_webezy_PubSubPackage_v1_PublishEvent_event]
# Packing all fields for [webezy_PubSubPackage_v1_Topic]
_msg_fields_webezy_PubSubPackage_v1_Topic = [_field_webezy_PubSubPackage_v1_Topic_name]
# Packing all fields for [webezy_PubSubPackage_v1_CreateTopicResponse]
_msg_fields_webezy_PubSubPackage_v1_CreateTopicResponse = [_field_webezy_PubSubPackage_v1_CreateTopicResponse_status]
# Packing all fields for [webezy_PubSubPackage_v1_PublishEventResponse]
_msg_fields_webezy_PubSubPackage_v1_PublishEventResponse = [_field_webezy_PubSubPackage_v1_PublishEventResponse_status]
# Packing all fields for [webezy_PubSubPackage_v1_DropTopicResponse]
_msg_fields_webezy_PubSubPackage_v1_DropTopicResponse = [_field_webezy_PubSubPackage_v1_DropTopicResponse_topic]
# Packing all fields for [webezy_PubSubPackage_v1_DropTopicRequest]
_msg_fields_webezy_PubSubPackage_v1_DropTopicRequest = [_field_webezy_PubSubPackage_v1_DropTopicRequest_topic,_field_webezy_PubSubPackage_v1_DropTopicRequest_force]
    
# Construct messages

# Constructing message [webezy_PubSubPackage_v1_ConsumeTopic]
_msg_webezy_PubSubPackage_v1_ConsumeTopic = helpers.WZMessage(name='ConsumeTopic',
                                 description='This is a client response message for starting consume from a topic',
                                 fields=_msg_fields_webezy_PubSubPackage_v1_ConsumeTopic)

# Constructing message [webezy_PubSubPackage_v1_PublishEvent]
_msg_webezy_PubSubPackage_v1_PublishEvent = helpers.WZMessage(name='PublishEvent',
                                 description='This is the publisher event message',
                                 fields=_msg_fields_webezy_PubSubPackage_v1_PublishEvent)

# Constructing message [webezy_PubSubPackage_v1_Topic]
_msg_webezy_PubSubPackage_v1_Topic = helpers.WZMessage(name='Topic',
                                 description='This is an object representing a topic',
                                 fields=_msg_fields_webezy_PubSubPackage_v1_Topic)

# Constructing message [webezy_PubSubPackage_v1_CreateTopicResponse]
_msg_webezy_PubSubPackage_v1_CreateTopicResponse = helpers.WZMessage(name='CreateTopicResponse',
                                 description='A response object from server once topic has been successfully created',
                                 fields=_msg_fields_webezy_PubSubPackage_v1_CreateTopicResponse)

# Constructing message [webezy_PubSubPackage_v1_PublishEventResponse]
_msg_webezy_PubSubPackage_v1_PublishEventResponse = helpers.WZMessage(name='PublishEventResponse',
                                 description='This is a response object from server after publishing an event to topic',
                                 fields=_msg_fields_webezy_PubSubPackage_v1_PublishEventResponse)

# Constructing message [webezy_PubSubPackage_v1_DropTopicResponse]
_msg_webezy_PubSubPackage_v1_DropTopicResponse = helpers.WZMessage(name='DropTopicResponse',
                                 description='This is a response from server once the topic has been dropped successfully',
                                 fields=_msg_fields_webezy_PubSubPackage_v1_DropTopicResponse)

# Constructing message [webezy_PubSubPackage_v1_DropTopicRequest]
_msg_webezy_PubSubPackage_v1_DropTopicRequest = helpers.WZMessage(name='DropTopicRequest',
                                 description='This is a request for dropping a topic from PubSub service',
                                 fields=_msg_fields_webezy_PubSubPackage_v1_DropTopicRequest)

    
# Construct packages

_pkg_webezy_PubSubPackage_v1 = helpers.WZPackage(name='PubSubPackage',
                                                messages=[_msg_webezy_PubSubPackage_v1_ConsumeTopic,_msg_webezy_PubSubPackage_v1_PublishEvent,_msg_webezy_PubSubPackage_v1_Topic,_msg_webezy_PubSubPackage_v1_CreateTopicResponse,_msg_webezy_PubSubPackage_v1_PublishEventResponse,_msg_webezy_PubSubPackage_v1_DropTopicResponse,_msg_webezy_PubSubPackage_v1_DropTopicRequest],
                                                enums=[])

# Unpacking package [webezy_PubSubPackage_v1]
_pkg_webezy_PubSubPackage_v1_name, _pkg_webezy_PubSubPackage_v1_messages, _pkg_webezy_PubSubPackage_v1_enums = _pkg_webezy_PubSubPackage_v1.to_tuple()
    
# Add packages

# Adding package [webezy_PubSubPackage_v1]
_pkg_webezy_PubSubPackage_v1 = _architect.AddPackage(_pkg_webezy_PubSubPackage_v1_name,
                                                    dependencies=[],
                                                    description='None')
    
msgs_map = {}

# Add packages messages

for m in _pkg_webezy_PubSubPackage_v1_messages:
	msg_name, msg_fields, msg_desc, msg_opt = m
	temp_msg = _architect.AddMessage(_pkg_webezy_PubSubPackage_v1, msg_name, msg_fields, msg_desc, msg_opt)
	msgs_map[temp_msg.full_name] = temp_msg
    
# Add packages enums

for e in _pkg_webezy_PubSubPackage_v1_enums:
	enum_name, enum_values, enum_desc = e
	_architect.AddEnum(_pkg_webezy_PubSubPackage_v1, enum_name, enum_values, enum_desc)
    
"""Services and thier resources"""
# Construct rpc's

_rpc_webezy_PubSubService_v1_CreateTopic = helpers.WZRPC(name='CreateTopic',client_stream=None,server_stream=None,in_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.Topic'].full_name, out_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.CreateTopicResponse'].full_name, description='Pass in an "Topic" object to create a topic to be consumed by "PubSubService" Clients')
_rpc_webezy_PubSubService_v1_PublishEvent = helpers.WZRPC(name='PublishEvent',client_stream=None,server_stream=None,in_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.PublishEvent'].full_name, out_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.PublishEventResponse'].full_name, description='A simple publication of "PublishEvent" to specific "Topic"')
_rpc_webezy_PubSubService_v1_ConsumeTopic = helpers.WZRPC(name='ConsumeTopic',client_stream=None,server_stream=True,in_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.ConsumeTopic'].full_name, out_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.PublishEvent'].full_name, description='A server stream sourced from a spcified "Topic"')
_rpc_webezy_PubSubService_v1_StreamPublish = helpers.WZRPC(name='StreamPublish',client_stream=True,server_stream=None,in_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.PublishEvent'].full_name, out_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.PublishEventResponse'].full_name, description='Stream a "PublishEvent"(s) on specified "Topic"')
_rpc_webezy_PubSubService_v1_ListTopics = helpers.WZRPC(name='ListTopics',client_stream=None,server_stream=True,in_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.ConsumeTopic'].full_name, out_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.Topic'].full_name, description='Get a streaming list of active "Topic"(s)')
_rpc_webezy_PubSubService_v1_DropTopic = helpers.WZRPC(name='DropTopic',client_stream=None,server_stream=None,in_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.DropTopicRequest'].full_name, out_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.DropTopicResponse'].full_name, description='Drop a specific topic')
    
# Construct services

_svc_PubSubService = helpers.WZService('PubSubService',
                                              methods=[_rpc_webezy_PubSubService_v1_CreateTopic,_rpc_webezy_PubSubService_v1_PublishEvent,_rpc_webezy_PubSubService_v1_ConsumeTopic,_rpc_webezy_PubSubService_v1_StreamPublish,_rpc_webezy_PubSubService_v1_ListTopics,_rpc_webezy_PubSubService_v1_DropTopic],
                                              dependencies=[_pkg_webezy_PubSubPackage_v1.package],
                                              description='None')

_svc_PubSubService_name, _svc_PubSubService_methods, _svc_PubSubService_dependencies, _svc_PubSubService_desc = _svc_PubSubService.to_tuple()
    
# Add services

_svc_PubSubService = _architect.AddService(_svc_PubSubService_name,_svc_PubSubService_dependencies,_svc_PubSubService_desc,[])
    

for rpc in _svc_PubSubService_methods:
	rpc_name, rpc_in_out, rpc_desc = rpc
	_architect.AddRPC(_svc_PubSubService, rpc_name, rpc_in_out, rpc_desc)
    
# Initalize all code files 
_context = WebezyContext(files=[WebezyFileContext(file='tests/typescript/publisher.ts',code=b'x\x9c\x95W_o\xdb6\x10\x7f\xf7\xa7\xb8\xe4\xc5r\xea\xc8\xe9\x80\xbe8s\xdb\xac\xc9\xb6\x00]\x13\xc4\x1e\xb6!\r\nZ:\xc7l$J#\xa9x^\xe0\xef\xbe;R\xb2\xc4\xd8\xe96\xa2hL\xf2\xfe\xdf\xef\xee\xa8\xd1\xd1Q\x0f\x8e\xe0\xbd\x129\xc2\xfb\x15\xce\xf1\xef\xb5,F\xd7\xd5|Z\xcdgfd\xd1\xd8\x91]\x97h\x12-K;*\xaby&\xcd\x12ul\x8dcL\xeb\x1bY(8\x83\x96\x12\x92L\xa2\xb2\xb0(\xf4\x1e\xb9`1/3a\xd1\xc9xDm\x98\xff$>\x89_\xbb\x13Q\xd9%1\x9e\xe5\xd2\xc2t\x99W\x19>J\x9b,\xe9n\xd4\xeb\xc9\xbc,\xb4\x85\'\xf8\x05\xadH\x85\x15C\x98\xa2~\x94\t^hM\\\x1bX\xe8"\x87\xfe\xfb{]&#\xfe\xef\xf8\xab\xe9\x9f\xb6|S+le\xf6\xd3\x8d\xe6\x95\xcc\xd2\x91\xd1\xc9()\x94\xb1B\xd9\x80W\x18\x83\xf4\xa3\xe1e\x9a"\xc3\x0e\x05E\xc8Tsk\x86\xde\xd7k\x91<\x88{l\xe8\xe3xD\xff|lL\'\xb0\xad\x80#R\x01\xb9T2\x97\xc6\xd6\\\xcd\xb6\xdf\xeb\xc1h\x04\x9f\x84|D\x10e\xa9\x0b\x91,]\x88\x15\xe5\tSHD\x96\xcdI\xa3\x81c8\xbf\x82OW3\xf8\xe9\nf?\x9f\xcd\xe0\xe6\xea\xec\x1c\x0e\x1c\x7f\x86\x16\x8c\xad\xe60!\xbe\x154\x16G\x83Sw\xcdW\xf1\x07\x8d\x94\x9eYQ\xca$zbt\x8c\xfb3\xd2\xe1\x0e\xfa\x9b\x81#\xe4\x15\xdb%\xaa(\xd2h\xc6\x81\xc3]\x017hJ\x8a\x13\x0e`\xf2\xf6\t\xb6\xac\xbc\xea\xf8\xc5Yq\xcf2\x06\xc1\xa53\xe4\xa3\xac\xb5\x9a\xe8\xc9\xf2\xdf\xae!Cwb\xc6\xb7w\x9b\x90\xd5\x99F^qt\xe7\xb8\xcf>\'\x80-\x82\xa7\x1d\xce\x7f\xb5\x8cWGc7\x1e\x89 \xa0F\x11j=\xee\xa2r\x8f\xa6\xae\x06"\x0f\xc5\xb9\xcd\x0fh-j\xb0\x05,\x85J3\xcaySV9R\x81\xa4\x86\xb1"\xccZ% V\x82j\xe5\x15X-\x94!D\xe4\xd0x/\xd5\xfd\x96\x9c$\x11h\x08J\x08\x99|\xc0\xd8i\xb9Z\x90)\x95\xa63\x92\x90b\x89\x8a(\xa9\x1c\xd7t\x08\xc5J\xc1\xa2R\t\x17\xb8\xc8\xa4]\x93e^cs\n\xb9\x90*\x1a\x90s\xbd\xc6+\x0bB\xdf\x1b\x82\x17)K\xd0\x98\x98\xb6\x8f\xb1\xc9(\x18\xd1w\x8c\xb2-])HoJ\x94\r\xc4#\xe6\x1cxQ\x8c\xd3/\xcb\x82\xc8&5a\xecv\xef\x82\xdd\x18\xfaYA\xc0\xe7M\x7f\xd8k\xa2\xfb\xc5U\xd3\x04\x1aZ\xb7}\x17\xec\xc6\xf0\xe6\xe4\xe4\xcd\xeb\x0e\x8f\x83S\x87\xc9\xef\xdf\x85[R\xd8A`\xcb\x9c\xd7\xed\xa8.\xab\xa6;qYy\x7f(\xd6\x97\x8abL%\x03\xc6c\xa3\xc9\'C}\xeb\xf3\xbe\xdatq\x18:\xa7\x86[M,\xb9\x16\xfc\xab\x95\x99K\x89k\x07\xb9x\xe0\xb4\x8b\x06\x04\xbe?\xeb\xba\x0e\x1d\x0e\x04\x1c^{(\x1c:,\x80T\x84\xb5\x85H\xd0\x89\xdcf7k\xebo0\xae9\xbe\xdfSJ\xb7w\x0e\xdf\xf5\xd2h+\xad\x9c\x0b5\x8f\xab\xc1"{\xc4\xa1\xc6\xaf\x98\xd8\xa6 :\x8b}o\xd5Q\x04n\xefN\x03\x82 \x80]\xcf\x12\xb1T\n\xb3\x1di\x01\xd1\xe4\xa5\x86\xe2\xd3\x1e\xf6\x92g\xeb\x7f\xf4\x92=\x8b\xec>+\xb9\xae8\xf0l<\x8f?\xe7*\x14\x0b\xf0z\x01i\x0c\xae)\x0b\t\x85\x8br\xe7N\xf7JkC\x14\x97\x95Y\xd6\xdd\xe9\xd9z\xe6\x03Y\xf0\x1b5\x08\x16\xec\xf5\xbc>9\xa1\x9a#QlR\xb2\xc4\xe4\x01\xe4"\x8c\x17\xdd%Y\xc1\xe5\xe9\xa6\x10#\x96\x9a\x91\x91)\xee$e\xc1\xad\xc3\xa0bb\xb1e\xe3\xd1\x00+\xc68\n\xcd\xaa\x19\x01\x95\xa6\x8e\x00\xd4\xce\xc0\xe3\xc1\xf9\xba\xc4g\xd1\xd8\xc9\xa4C\xe7\xa3\xc88\x8bh/\xeb]\x14\xbd\x10u\xf2%\xea:\x13{\x93\x06/$( \xadT\x9b\xec\xc1\xe9^z\xe7\xd1\xd6\x88\xc6\xb6\x17\x88k\xdcGm\xde\xf6\x10n\x82\x93\xcd\x90\xf2\xd3f\xb0N\xe6\x86\xc7\x02-K\xf9k\xfd\xa0\xf8\xfbYK%\x1d\x82\x86\xe3\x96\xec\x8ea\n\xa1\x9f\x16/\x0cz_\x0e\x9b\x8e\x91\xddI\xd5\xbf\x95w\xb5\xc2\xd4\xeb\xdb\xf6\x158~\xdb\x1f\xeeQ\xd8\x91D\xc6r\xfdm\x01\xee\x91\xf0g\xc5\x90l\xc6\xcd\xae\x13\x9e\x94\x19\xb7\xb6w\xdb\xd27\x0c\xbd\xc1D\x12\xe0\x1bK\x1d\xc8\x8e\xdfB\xf3p`\x91\x1dv\xff\xb8\x8b\xda\xbbx!U\x1aa\xc6 \xc3,v\xaf\xe4\xc9dR\x0f\x8a\x01\x1c\xd0\xefJ\xa5Hd\x98\x0e\xfb?\n\x999]\xc0|\x0e\xd6\xdc\x01\xbdn\xa9\xa0m=m\xcc\x0e\xfaax\xae\xfd\x0b\x9b$h\xb2\x95lW6\x88E\xfd\x02\x0f\x93X3]0\xf5\xb3\xae\xe6$\x8c\x9f\xa6E\x8e\xe742\xc6\x87\xfc\x0b\n\xb2M\x03\xcf\x90\xc3\xcd\xd0\xca\x9c\xe6\x99\xc8\xcb1[KT\x84\xfb\x97\xd3\xff\xea\xae\xb1\x91\\u\xd2\xd9\xe1\xcf\xedL\xfc\xdc\xef\x0fk+\xebA\xbe\x01\xf7*\x02~\xe6\x14z,\xd4z\x10\x02\xd8\xd9\xe4.\xfdK\x87\xf0\x11\xc7q\x97\xe2\x92\x1f))r\x87\xf0t\xd4\x9d\xce>\xde\\\x9c\x9d\xff\xf1\xe5\xe2\xf7\xcb\xe9l\n\xd1\x07\xa1\x88\x9d\x1b-\xac\xea\xd6\xc3\xa5\xc2\r\xae)\x906\x1d\xc7\x94\x1e\x92\xf1\xa0\x8a\x15\xe5\xec\x9e\x06\xca\xb2\xa8\xb2\x14\xe6\x08i\x91T9\xf9E\xfe\xad0\xcb\xf8-\xd4\x8c\xeb\xb3\xeb\xcb\xb6,\xb9\xc98cbg\x1a\x03\xc3\x7fZ\xc4\xa1e\xcf\xbbN\x18\xcf\x83;\x985e\xe4\xba#\x88\x8c\xccM\xd7\x80\x7f\x11^\x0c#$`\x0f\xcb\xbf\x13\xa3Y\xc7\xe9T\x17%U\x94\x9f\x95\xde\xe3\x1d\x16\x86\x13\xd3\xcd\xeaWO\x07P\xe7\xcdq\xf4D\xef\x89\x04\xc7VW\xe8\x8bf\x1ct\x89=\xb32t\xef\xf8\x0eXX\xb9\xadAn\x12[\xad\xbb\xdc<+\xddp8\x96\xfe\xf3Kr\xe6\xd8\x8b\xfa\x9d\xc9\xdf8;\\\xdetO\x11v\xd2\x00z\xdf\xca\x84\'\x08\x99\xdb\x0eL\xe5O\xc5\xfa\x9f\xb97u\xc3\xeeq\xcf&\x97n*\xf5\xfc\xd9</\xd2u\xcf[\\\x7fDufY\x10\xc3\x0b\xea0)L\xfd\x87\xe2\xa0\xb7\x19\xfc\x03)\x08\xcc\x9e'),
WebezyFileContext(file='tests/typescript/subscriber.ts',code=b'x\x9c\xd5W\xdbn\xdbF\x10}\xd7WL\x8c\x06"m\x99T\x8a\xa2\x0fr\x9c:H\x1c Ek\x1b\xb0\x82>\x18\x82\xb3\xa2F\xd6\xc6\xe4\x92\xe0.\xed\xba*\xfb\xed\x9d\xd9%ER7;o-\x91X\xe4\xee\x9c\xb9\x9d\x99\xe12<<\xec\xc1!\x9c)\x91 \x9c=\xe2\x14\xffz\x92ixUL\xaf\x8b\xe9X\x87\x06\xb5\t\xcdS\x86:\xcaef\xc2\xac\x98\xc6R/0\x0f\x8c\xb6\xc0Y\xb5#S\x05\xef\xa1\x91\x84(\x96\xa8\x0c\xcc\xd3|\x8b^0\x98d\xb10hu<`\xae\x19?\x0c\x86\xc1\x1b\xbb"\n\xb3 \xe0\xfbD\x1a\xb8^$E\x8c\x0f\xd2D\x0b\xda\x0b{=\x90I\x96\xe6\x06\x96p\x8d\xf9\x83\x8c\xf0<\xcf\xd3|\x00\xda\x08Sh(a\x9e\xa7\t\xf4\xcf\xee\xf2,\n\xf9\xcf\xf17\xdd?i\xc3\xf6\x08\x86\xd3B\xc6\xb3P\xe7Q\x18\xa5\x8aT*\xd3\x05\x0b\xad\x91nj0\x0b\xa51\xb6E(G\xba\x98\x1a=p\xd1^\x89\xe8^\xdca\r\x08\x82\x90\xfe\xb9\xec\xe8VjY\x03\xc5&\xf4\x93\x8a`^\xa8\xc8\xa64\x11Ry>,{@\x97u\x08nM\x9a\xc9\x08N\xa1?&r\xc6\xfc\xc0X\xbab4\x94\x84bJ{\n\x1f\xa1\xf6\xc3\xf3\xdd\xb6\xfd\x13\x86\xf0\xc5\xc8\xd8Z\xb0\xe4$\xe2^\xaa;\x10@\xb2\r\x959\xea\x8c\xac!1\x95\xd2\xde\xc1\x15\xf9.5\x1e@,\xef\x11\xa42\x98\xcfE\x84V\xe5\xcaY\xaa\x0c\xe7\x0f\x99\x1cU\x88\xb7\x9d$\x04v\xfbf\xf2\xae\x8a\x88\xaf\x1cM\x91+\xebq\x85\xf1<2\x9f\xc6\x0f8\xc8\xf1\x1bF\xc6\x87\xd36\xa0\x0e\xb51G\x01\xdfLN:\x02\x14\xe7gE\xd5c\x16\xd8\x8d,\x12\x0b\xa50\xde\xd0\xd6\x11:\xb5y\x0c~k\x02\xea\x86\xf1\x81rS$h\xf7\x02\xe6\xf5\xd7\xeb\xcb\x0boY\xfa~G/_A\xa5x\x8a\xderc\x93/\x85\x7f\x9a\x11p\xc8\xa3-\xb9\xda\x12\xfbZ\x98\xef\xb3\x0c\xd5\x8cy\xe2X\xb9\xb1lf \x9d\x83q\xd9Aj\xb0\'"-\xa2\xec\x12\xd5vu\xa7\xc6&\xabAV\xe8\x05\xfb\xb5\x19\x14_\xe5`\xeb2r3R<\xd5\xafPO\xcf\x84\xe08v\xf2\xdb-\xed\xb1F!e\xc4\x1e\x92\xc1g\xccT\x8d\x1a\xc4\xe9\x9d\xd7\xbf\x91\x138W3\x9c\x11\xcf9\x8a\x84\x93\xd5\x90\xdd\xdf\xe1F\xb9\xb1\\\xfa\xbd\xf5\xaa\xfbCH\xc3YvI\x7f3\x1cB")\xa7\xccO\xb4\xc0\xe8\x1e\xe4\xbc[k\xb4\x17\xc5\xa9&_\xec\x80\xa0\xe9BH\xd0r\x86\x1b\x05=\x07\xaah\x8d\x8a\x85\xc5\nF\xb4+xDzD\x91\xb3i\xee\x9e"\x8f\xa8y\x05\x15\x86\xeb%K<\xd5G\xb746\xba\xc0v\xf6\x83\x88\xb9\x03\xd0|\xae\x9e\xbc]\xc9\xa5X\xbcv0\x81s\xc9\xdf\xc1CG\xb4PMg\xf8\'\xdb\xd9\xe5\x88VN\xd4\xbe\xed\x10\xaef\x86\xd7\x14\xf0\x16\xc1.\x85\xe5\x80\xf8i\xc8.\xdd\xad\x931\xc4^\x13\x05\xe7\xc6\xa5\x8c\xcb\x84\xb2#\x1e\x89\xe7\xce\xc4;iJ\xa1\x91\x0ch\xc4\x9e\x8bh\xe1UC{=\x89\x1bUi\xb5\xc1\xf1\xbb\xfe\xc0":\xcemzC\x8e\xb4mI5\xf30f+\x18\x07\xf6\x95~zzZ\xbd0Zpf\xcd\xc1_\xd1vA}@\xc8M\xd6\xba\xbe\xfd3\xb1\x1d\x82\xca\x8d\x10r\x11\xfaGV\x8b\xb5\xd4m\x19;=\xdbC\xf2e\xf3\xd3\xaa\x1b5J\x9f\x99\xa7[f\xe6\x95;\x9f\x9c?\xd0\xdbu\xcf@\xb0\t\x94\t\xce06\x82\x92\xf8\xbb0\x8b@L\xb5\xc7o\xa1\x8ft.a\xd5\x01K\xd0\t \xc9\xfc\xe0\x0e\xcd\x98\x9e\xa8\x0f\x8ea%\xd3Z\xdeU\xc0\xad\x14\x92\xc6A\xa2\xc7\xa9\x05\xac\x8co\x89\xb0l\x91NDj\xdc\xcb\xcb\xd1\x04>\xd0\x083\xab\xc9\xee\x98\xb9]+\x1f\xbe\\\xcd:n\x18RQ\xb3\xe4T\x8f\x1c\xa0\xf4\xbf\xb7\x04\xb6\x19\xfa\x9f\xd1\xff\x9fe\xdf\xb5lIg\x16:\xfcV\xaf\xd4v\x97\xb6\r\xd8\xcd Jg\xadV\xe4Fo\xd6\xed0p\x87\xe4\xe0\xe2r|\xfb\xe9\xf2\xcb\xc5\xc7\xfdM\xffj\x02\x17i}\x8c\x98\xa7\x85}\x9d\x1cG\x9dz[{[v\xe7f}}\x7f\xe95(w\x06\xee\x0e\xee\x9d)\xd9\x99\x9a5\x05\xbd\x97\xf7\xd8\x1a\xbc\xec\xd5\n\xf8\x7fsR\xaf\xc9\x9d\x15\xb9\xe0\x95\x91*\x92)\xae\x9c\xe3\x9a\xa3\x93\x00\x95\'\x92\xf2\x99\x1e\xd1\xc9\xa8\x9e<\xf38Mso\x85\x84\xd7|n\x18\xfa\x10\xf2\xaf_\x9f|^\x00\x0c+\xe0k\xf8\xb9\xc1\xd1\xa1\xaf\xa0\xef\xb8\xfd8\x8f\x81\xf4\xe9E\xb85\xf8\x82\xce\x12/\x067\x1a~\xfc\xc9vEo\xa5\x82\xe0\x9e\xbbyK^\xfa\xf0\x0b\x1c\x0c\x0f\xe0\xa8\xda\x1c\xb9_\xd7H\x95\xc7\x8c\xa8o\xbb\x98zuT\xdf9\\\x95!\xc6\xd5\xb7]\\\xbd:\xaa\xefV.V_!\xce\x99#8\x18\xb5\xcd\xd4\xcf5\x9c\x9e\x03\xb7\xdf\xf0I\x8f}\xf8\x9b\x06b\x9d\x97\xa3~b\xbf\x1cm\x99\xb8\x1a\x0el\xd5rA\xb5fS\xbb\xd4\xber\xc7\xd9\xcfY\xf8aIb\xe5W\xaa\xbb\xd2\xff\x17\xc6\\{\xc0'),
WebezyFileContext(file='services/PubSubService.ts',code=b'x\x9c\xcdZms\xdaH\x12\xfe\x0c\xbfb\xe2\xdaZ \x01\x91\xfb*\xc7\xdex\r\xd9\xf5Ub\\6\xd9{\xf1\xb9\x82\x10\x03h#$N#\xecp\x0e\xf7\xdb\xaf_F\xa3\x11\x12\xc6v\x92\xaa\xabJ\xe1h4\xd3\xdd\xd3\xd3\xfd\xf4\xcb(X,\xe3$\x15\xf7\xa2^\x9b{\xd1$\x94\x1f#/Y\x9fza\xd8\xceFN\xc3@F\xe9U\x9aHo\x11D\xb3\xc2\xbb+\x99\xdc\xca\xa4\xfa\xdd\xaf\xc1$\xd8~\xa3d4!\x0e=/\xf5\xe0\x99\xd7\xf7V\xcbP~\xe1\xb9f\xf0Rz\x13o\x0c,\x8a\xc3\xb6|<\xf2\xb7$H\x0b\x13U\xea\xa5+\x05\xff\xf9\x18\xa5\xeb\xa5\x9c\xfc\xce\xdb\xe05\x1fd\ntS\xaf.6b\x9a\xc4\x0b\xd1x;K\x96~\x17\x7f:\x7f\xaa\xc6a=\xc8T\x82\xe4\x03_\xf6\x93$N\xccl\xa7\xbbJ\x83Pu%\x8e\xda\xb3O\x96\xc1\x10\xb8\x95&\x06Q*\x93\xa9\xe7\xcb\x02\xed\x8b\xd5\xf8\n\xfe1\x07\xdeG\xbb<\x08\x7f,z\xcb$Nc\xd5-\xcc\xcai\xbe\x14\x9e\xd2\x14.<\xff\xb37\x93\xd5\x0b\xf5\xcb|a\xff\x16\x8e\xb7\xbf\x08R\x90S/\x918T\xd4\x05\xe9\xb4Zg\xdd\xf1*\x08\']\x95\xf8]?\x8e@\xfb\xbc\xb6.\xbf\xd0b<\x03\x91Hx\x15I?\r\xe2\x08\x8e`\x1eO\x948\x12\x8d\xde\xe5\xe0\xa2!\xbe\x8a\xc6e\xfftp~\xde?\x1d6\x04\xac\xf4CO\xa9\xa2:\x04\x88\x12\xca\x05\xcaU\xad<\xad\xff7\xa5C?\x16\xf7\xf5\xda\xf5\x82\x98\xbaB\xa5\t\x98\xe3\x8d+\xbch\r\x9cj\xd2\xda\xbd[\xd4\xc5\x91\x88\xe4]a\xe8\xb0^[&\xc1\xad\x97J\x91\xc6\xcb\xc0\xff\xe0-]\x01?o\x98j\x1bh\x1e\xebe0\xdalY\xf3\xc16\'q\x14\xaesM\xa0\xb4n\x95bl.wA\x18\xcc\xe6\xe9?\xe3H\xee\xe3D\xbaOV~\x1a\'MC\xd5\xad\xa0\x7f\xc4jo\xa1^j\xe9<PNA& k\x9e\xeb\xb5\r\xe8h\x92\xc4\xcb!\xee\xd7\x15[ \xf1\xa6`SN/\x9bx)\xff\xbd\x92*m\x8b\x9d\xef\xd5\x12\xc4\x95\xb8\x87&H\xe1\x03-Wly\xf87\x13ok\xcac\x98\x01\'oc\xcfn\xdazm\xbd\xd6\x12Gd:\xacX\xf0\x01:\xf2\xb6\x98\xc6\t\xb9\xe5\x91@\xda\xa0;\x92\x06\x0e\xa0\x16LE\x93&\xb1j\xf9\x19\xf5\x9b\x19\x8b3\xf7\x14\xcfp"o![z\x1eLl\x12\xd5\xec\xb9\x16J\xf0\x1b\xb9`\x99\x80S\x91\xcaL\xa66\x15^b\xa6;\xec\xbd \xd8"\xbe\x95\'a\xf8>P\xa9\x8cd\xa2\x9a\xec\xd8\x8dlE\x81\xe8D\x02SY\xa6\x8b\xbb\x8fC\xe9\x84\xf1\xac9\xba\xee\xdc\x08\xd4\x158\x18\xab\x83\xf1`\xe1-E\xe7X\xfct\x9f\xaf\xde\x8c*\xd7\x07\xf9\xfa\xa1\xe6\xcc+\xffz58w\xd8\xb8\x83\xe9\xbaiv\xd3BBL\t\xb44\x18\xff\tV\xe9|\x96k\x95Oq\x96\x126\xd7rB\x19\xcd\xd2\xb98\x16\xaf\x8d\x1e\x0b\xdc\x1b\xc8\x1d\xad\x00x0w\xf8\x15C\xcb\xc52\xcdh\xd5Xo\x1cU\xd0y;\x97\x8fWl\xf4f\xb5\xb55\xa3\x15D\x1bV\x87k)\x85go\x84\x0c\x95\xccd\xcc\xd7\x803\xdb1\xa7\xc9\x81\xcc9\xf9up9\xec\xf7\xda\xa3\x931\xe0)h\x0e\xfdQ\x00\xa8CLQh\x8e\xe2\xba\xa0\xf9\x1b\xf1B\\x\xfc\xca\x07\xd8\x00P\x00\xf8\x9c\x8au\xbc\x12w\x00\xcepr\xda\x88\x89\xd0\xdd\\F"\x0cn\xa5@e\xad\x16\xa0K\xe1%\xf4\x84\x10@\'\xcd\x87\xed\x8cZz\x03\xf4[\xdf\xde\xca\xde\x9d\x9c\x0f\x86\x9f\xde\r>\x9e\xc3^X\xff\xdb\x82Gq\n\xa2\xad\xa2\x89\x88#\x01~\x05\x82\xbf\xd0L\x91\xa7\xcdm/\xb3w\'g\xef\xfb\xbdO\x17\x14Zzg\xc3\xb3\xc1y{\xf4a\x05\xae\xbcD\xe5x\xda\x80c2)\xdc#j\x83\x99!/\x80>\x8c\x0f\xdd\xaex\x0baN\xbc}{\'\xc7\xf2?\xeb \x16\x1d\xd1\x1b\x08\xd8\x8a\xb8\xec\x7f\x18\xfc\xd1\x07\xb4^\x8dC\xa0\xe4\x03\xc6\xa7\xf2Q@9d()\x0e\x9e\xe6\xeb\x9f\x83\x8f\x8f\xa6\xf9xX\xacZm\x01#\xe8\x06\x81*\xd1\xaf\xdc\ny@\xfe{\xc1\x07\xe2\x8a\x83\xabx\x81i\x1a\xf8\xdf\x81\xd8\x1c2\x85\xa2\xcbd\xb40\xa0\x19\xe0E\xe3\xa8\x00\xdc\xfa.\x84\xb5\xb1u\xbfw\xbd\xbf\xec\x9f\xf4\xfe\xf1\xa9\xff\xf7\xb3\xab\xe1\x95e\x98\xda$OB\x0c\xddk!\xbf\x00\x8c*p\xad\x8e\x18&kH\x1f&\xfa\xc0)\x08\x03D\x88.\xfbS:\xd7\xd9\x81\xb8\x0b\x00\x8eLhi\xb6\xc4\xe5\xc5\xa960\xdb\x90\x0b\x10\xf5\xf2F\x9cE\x06\x94\x04\x05\xfeF\xbb\x8cG\xf9>\xeb%(G\xac"\x94b\xb7\xe4x\xe0n\'3\xcdV\x9b^\x13z\xba\x0fp\x10\xbf\x88\xf2\xdb\x99\xe6\xd1b\xf4\x15\xae\xb8\xdf\xb45\n\xf8s\xe9^\xdf\xf0S\x08\x1aR)1\x07\x03\x93\xcd\x16\x88yv5`+h\xb2g[[\xb0Y\xe8\x88D\\\x0e\xb755\xba~u#\xd8>u(\xe18B\xa7\xf6\xaf\xa8\x1cPJ\x11\xd4\x92\xbe\xa5\xa3\xd5\x16|k\xbb\x1d\x9d\x82\x85\x00\x00w\x86\x83\x8b\xb3\xd3\xdc4F\x1b\x8d\x15\x9b\'\xc1\x04\xfdQs:\x8a}8qa\xcd\xddvm\xfb\xdds\xf0\xe2\xc9\xb4\x1f\x8f\x1b\x95\xcb\x8b\xc0q)\xfd@\xdeBe9\x13X\x8eq\x1e\xa1U#\x93R\xd6E6\xdcN\x83\x05\x18\x93\xb7XV\xa3A\xd1>\xc0\x930\xbcdK~)\x1a\xde\xe6\xc6\xcd\x82\x0f8\xf9o\x10w\x88\x05\xf8w\xc9t\xe8E\x96\x87\x80\xe8\xe4?\x98C\xf0\x8ae\xacT0\x86\xcc\xde\xf7"!\xe1\x9dX\xac\xc24\x80j\x85\'(\x01\x11\xda\x9f{A\x84\xd0\xb0\x10\xf0w\x11S|\xc5\x8a\xe6\x8bP\xbe\x045\x06\xb1\xaa\xc43\xb4T{\xa3\x8eN0_\x1c\x1d\t\x88\x93r\x1aDr\xa2\xb1\xeeQ+\xb3\xf4\x10%\xcd\x12\xc2\xb6=\x8f<a\x7f\x02ZA\xba^HC\t\x07\x9c\xe5J\xcd\x9b%\xf2\xf9,\xc6\x87\xad\xd3tv\x9dZ5\xd6\x95Ei\x8bb\x82\xd6}\xf9R\xe0_\xa8\x92\xcf\xe1\xa8=,\xc7B\xdc\x14\x9c\xe2,\xc6_\xc87\xc0\xee\xa4\xe38\xd9D\x80a\x9c\xd5\xb9\x8b\x93p\x02K\xd0L\xc7\x1e\xa0\xf6]\x12\x00\xea\xaby\xbc\x82\xf1\xb9\x07\xc9l$\xbc)V\x8c2\xb3\x0c\x8c\x01l\x1d\x90W\xa8\xd5X\xf9I0F\x98\xd4\xb4\xafb\xd2\xa88\x00/J\x0ft\x80$\x03\x1a\x03\xe5\x18\x8bU20\x08\x12\xb9D]\x91\x81 \xc5\\\x17\x92\xbc$\r\xbc\x87\xfc\xda\xc6\x85{\x8a\xb85X\xe9h~Gb\xd4\xff\xa3\x7f>\xec\\|\xfc\xf5\xfd\xd9\xd5\xef\xfd\x9e\xc8}bD.\xc5\xaeJD(m\x86\xed\xf8\xd4\x0f*\xc3\xe5# \xc4A/G\xef\x82\x02U\xb5\x08\xd4\x1f\x97\xd2]\xed\xce\x1f\xcb\x87_\x99G\x16\x12\xbb\xa7\xa5u\x9c\x15\x17\xf2\xba\x8a\xbe\xd7v\xead\xadzH5U\x88]\xech=\x97\xb0\xc1\xdbm0\xad\xac]\x8b\xd8\xf9_\x88\xad\xc4\x07\xcf<\xaf\xec6b\xbc\xe6GZ\x0e0p!1\x91\xe0\xf0\t:=\xd5\'\x08EE\xe0\xcf!\x01\nC\xb4h\xf0\xde\xd9\x0c\xbckB\xd5\x8a\x04`\xa0\xa4I\xc3\xbd\xf6\x14r\x1e91\xd2f\xd6\x80\n\xa2\x19\xee\xee\xcd\x9a\xc8\x82B\x9c\x00\xdaJX\x87\xbc0\xbc\xc3\xc9\x02\xae\xb2\xd9\xc2\x9fX\x81\x1cySD\xdcA\x1d\x04JH\xe2\xb5\xe5\xb6\xa1\xae\x99\tp \xdd\xe3L\nQ\x91(j\xfd\x19\x05\xd0[`}6\xb5\xd2\xbfx\xaa\x89\x81\xa3+La=ea\x01\x9a%\x10f01X\x91;\x17\x96\xbb4\xccF-\x8e\x00\xf0\xed\xe6\xc2\xf6\x91\xfdt\x8f\x92\x81\xedc\xe0\xbb\xe0\xe20\x0fRth\x169S\x9e?\xb2\xd3Pj2P\xdet]\xd4\xc2\r\xac\xd7<v\xe0\xf7aU\xe7\xc1\x94\xd6\xa5\xaa\x9a\xc8\x93\x86\x9a\xba\x96\xb6\xb6\xc09\x81\x1e\xd9\xca\x0f\xdcm9 \x87\xdd\x1eqE\x9e\x94n\xac\xbav\x03g\x9b\x82\x856\xa9\xc5\xebz\xd1\xbae\xd5\xb7\x8e\xb6\x95\xbd\xd5z\x03u\x82Go\xa2tCW\xcf\xa8riz\x8ce\x85[{\xe4\x05zr\x16\xb9\xe3\xe9\xb4\x10\xb8\xd1I\x8c\x05\x129\xbb\xa9\xf9\xc0\xf4Rk\xe7\x12[Fh4\x99\xf9\xef\xb2\x1b*\xc6\x0fu>D\xad\xd6 K\xe4h\xf27\xa72\xfbt\xb4#\xfbx\x8a5\xef\xb7\xe5]E\xcbau\x1aRe\xc3\xdbG\x17U\x1c\x85\x86-\xa3F\xf9\xc5\x97K\x84&\xc5U&"\x96N%\xb3(I\x84\xe8E\xa3-\x9a9\xfa\x95\x8f\xf4\x94\xf1N\xe3\x0e\x91\x1dUZ\x15\xb7\x0b\xb3^a\xb5\xc5lXX#\x01_\x82\xb4\xd1S\xd8Ov\xcb\xc1\xb7(^\x8a\rx\x08jhUI\xe2\x80/*\xc0\xf2\xcd\xf7\x13\t\x8c\x08\x82\x02\xc8\xf4\x900\xefh\xd2\xf7T\x0bw\xc3\xc8&\x86`\x92\xa7&\xbcp\xe9\x8f\xd3\xdb\x1a\xb5\x98~N\x81\xdch;\r\xda\x0b3\xcfH\x85\xd0\xc7\x92\xedlHw`\xf6\xf2\xfbx~\xf6\xe1\xe2}\xff\x03\xa4\x8b\x00n\x07|\x95\x80\xf0\x86\xf4\xd7\xe0v\xe6~FN\x0eZx(O\xcb\xb2\xd8,tL\xcf\xd2\xac\x8a\xab\xc7\x1fP \x17o\x1a\xff\xaf\xaa\xe4\x07\xdak\xf6\xeao\xeb\xb2\xed\xeb\x90\xfd\xe8\xa3\xc7`C6\xac\xbeOzM\x83\xdf5\xaff\x8a\xd6\xd1\xe0\xb9\x90Se\x81f\xea\x81\xfb\x96\xf3\xe8\x0e\x80\rb\x07\x97N\xb8E\xcc\xa09\xf3\xcb\xf3\xe8\xa2\xcb\x8a\xaf\x95\xe3\x8aA\x12\x93\xda&\'\xc8\x9f\xe5\x1as\xccb \xa2\xab\x11\xd3\xfc\xb4\x84\x81\x17\xedF\xb7X\xea\xebD\xaa\xf1\xb5jX\xb5G\xef\xcc\x16]\x90\t\xf9a\x16Z\x9e\x8a\x1dB\xbcdpI\xa6 \xaa\x98\xa2\xf29\xb9\xe24\xeec\xaaPA\x14\xf3\x82F#\xbf#\x13\xcd\xdd\x12\x98\xa4\xb8p*\xc8\xb0\x9cIb\xf7\xce\x05R:\xe9\xab\x8d\xc1\x1a>\x1f\xea\x9b\x19\xebR\xa3Z,\xa5\xef\x99\x8e_[\xb7w\xbb\xb7\xbd[\xb0\xc3\xbd\x92mJ7,;\x88\xec\xa6\xb1\xd10\x8f{\xb1\x17\x1fi\x93m=+\xe4\x1c\xf4\x82I\x94\x85\x15\x08\xfcb\x81\x19sv\'\xc8wRX\x07\x91\xa1\x1f\x94;\xde\xc8\r\x80\xb1i\xfa\xa7\xf9\x8d\xf7\xae\xe8\xe9~\xcf\xd2\x98C\xb1\xab\xef\xd2uD\xc6\x0c\xc6D\xe5<\xed\xb7j\xbeFC?\xd37\x1d\xb7^\x08c\x90\xf8\x9d\xe9\xa7\xa6\x95s\xe45#\x00!\xde\x17`\x1fH\x92M\xf9\x80q\x91\x0c\xa9*L\xb1@\xf6n\xbd \xc4M\x99v|u}i{\xf3\x01\x96\xe8\xa8+\x83,\x86.\x9e\x96Dt9x\x85\xb4\xdaV!Q\xba\x8b\xa5\x1a\x85\xaaet\xf0]\xd9ru\x82\x8c@\x95\xaaG\xac\xe6\x16\x9f\xb9\xc7\xd5e2\xc9\xdc\x1b\xf4\xaf($\xd0\xed\n6k\x94\xfe\xdc\xa3c\x8ard\x0b?\xbc;\x03\x05;\xee\xd5[%\xd3\xde\xd6\x1b\xde`3\xe5\xb2\xeaHi\xc5m\xda\xea{b\x018,\xd0\x06\x11\xc5X\xca(\xeb@\xbc\xc8\xca\xc1\x9a\x1fJ/1F\x94\xd9\x96}\xd3\x8a6D\xc4\xc0f\x82\\GX\x1d\x18\r\x06\x91\x1f\xae@6r<j7\x90%M\xb9\xf9lt\xa7\x91\xad\xa24{\xe8\xac\x8b5\x9a\xf8\xf9\xe7\xbc6z\x1a\xa1\x16\xfe\x7f\x0858\xf8\xca\x9bG\x10a\xdb\xb1V\x99Se3\xd2_\x10\xe59\x89ZJ?\x98\x06\x92:\x7f\x8c\x19|\xc3\r)\x7f\xca\xba\xd1\xdaKq\xf4\x8e/\xc1\x97Y\xd36\xef\x0b1\x17cj[\x9f\xc8\x1ce\x1f/U\x7fj\xf0mf\x86{\xb3\x17\xa3\\0;\xe3\xf3C\x8c\x90\x1b\xbd\xba\xfc7\xf8\xd6\x11\x01\xb5\xaf&\x90";\x19\xff\x07\xcc5\xfb\x0e\x02oIt\x08E\r\xc7\xe6\xbb\x83\x94\xa1\xd0h\x937\xa7\xa5\x83\x17\x84\x03(\x02Y0\xab\x8dd\x06;\xd6\xa1\xdc\xc4\xe6]\xe7\x92\x7fK\x96\x1f\x0e\xed\xaeC6\x90\xb5\x15\xb2\xaf\x1a\xc4+\x10\xa7\x83M!\xeeF\x92\xdbx\x0c\xfa\x8a\x92S\x8eg8\xb7\xe2\xa8G\xd7/\xb0q\x92\x7f-\x91w\xe2\x80C#\xeb\x9c6\xb2\x86[\xed\x19m\r\xab,\xe5[\x95i\x10\xe2\rnS\x86\xfb\x9a\xa22,6\xc1\xacG\xcb\x15\xed^\x985|\x9c\x0fg\xfc\xf7zu\xcb\x01m\xf5AJ\x92\xee\x81(l\x15\xe8\xc5\x14Ff\xc6T\xdbl\xef\xfeY\x9d\x9a\xda\xe3\xda0\xc6P \x8d\x00\x13\xc4of\xb4mk\xd3\x16:E\xb4?\xde\xc1v3\x84\xa7Y\x0c\xe8\xc3W\x98d=\xd1\xc4\xb6\x97\xa2\xb9\x1c\xdd\x18\x13\xe9\x1c\xe7W\x90y\xd2#~\x1b\x0cz\xa3\x9d\x1d\xc9VEW\x83_\x1cZ\xf1\x95\xdd\x0e\x94D\xf9\x19\xbdW8H\x1f\xfe\xd0g\x88\xd8\xd7(\xb8\x1f\xc9\x9f\x8b\xfdP\x94\xad\xfeP\r?\xe6\xda\xdds;\xb4\x10\xd5Z\xa1o\xe0\x8d%\xf0\xad\xbf(O\xb9\xc6\xdf\x1b=ko\xf7\r\x86[\x95\xde\x9a\xb59\x0b\x9e\xca_\xb5\x1a_\xd5\xc0@lG\x05d\xcb\xbf|z\x10\x07\x0b\x18\xcd;\xa7\x95\x98\xef\xb6\xc5_^\x7fz\xfd\xfa5\x0eC\xe6[\xdf\x98/eA\x05\x85O[\xdb[\xcf\xfaO}s\xf8?\xb1|\x0e\xe2'),
WebezyFileContext(file='services/index.ts',code=b'x\x9c\xe5Z\xebo\xdb6\x10\xffl\xff\x15\x87`\x80\xa5\xc0s\xd2\x02\xfd"\xd7m\x83$\x1b\ntK\x90\xa4\xd8GW\x0f:f#K\x1aI\xe5\x81\xcc\xff\xfb\x8e\xa4\x9e\x16m\xcb\x89\x9d6[P\xa4\x12y\xbc\xf7\xfdx:\x84\xce\x92\x98\tx\x04\x9f\x91\x80D\x82\xba!\xef\xc3\x1fD\xb8\x81+\xdc>\\\x12vK}r\xcaX\xcc\xc0\xe50\xe6zaL\xe4J\x1f\x8eC\x8a\xa7\xbeF.{8v\xc30_8I\x93\x90\xdc_\nF\xdcY\xbevA\x90\xa7\x17\x92\xfa\xea_\x8c\x8ar\x15\xe60a\xf1\x0cz\x9f\xaeY\xe2\x1f\xc8_\xbf~\xe7\xbda\x97\xe6z&\xb8M9\x9d<\x14\xa4\xa9\xa0a\x95\xe2\xcc\x93:J\x9e\x05\t\xbb\xaf39O\xbdK\xfc\xa7M\xd1z\x14\xb4\x83\x03\x14!b~P#\xea\xe5\x87\xf7\xa5\x17\xf4\xd6\xb9\xeb\xdf\xb8\xd7\xc4|.\xdb\xecu\xfd8\xe2\x02\xc6\'\xa7\xbf\x1d}\xfdr5>;\xbf\xfa|\xf6\'\x8c\xe0\xb1\xdb\xd9\x93\xf6\rn\x08I\xdc\x90\xde\x92\xb1\xa032\x9e\xf1=\x07\xde\xbc=\xc4\x9f~N2\x15"y;\x98\xd1H\x93xD\xdc\x11\x12\x8d\x13\x1a]s\xe3\x81:\xcf8\x15\x9a\xca\xc8\xd5\xbd\xcf\x18\xddQ1\x95\xa42\xf2Hl\xe2\x96\x106\xa3\xa2\xa0\xf41\xe4Jz\xbf;\xefv\xc9\xbd\xf2\x90\x1f\xba\x9cC\x92z<\xf5\x04G;\xbb\x1d\xe5\x03\x96\xfa"f\xd64\xe6\xc2\x01|E\x99\xe8\x86\xbd0F.rq\xaf\x0f\xf2\xbc\x03Q:\xf3\x08\xc3\xbdw\x87\x87\xef\xde\xf4a\x96e\xa3S\xe4%\xeeE\xe4\xaex\xb5l[\xba\xb3#\xa6\x94\x0f$+\xdc\x97\xff\r\xf35\xa5\xd7H\xb1/\xd6f%\xaf\xfc\xb1\xd8\xab\x85~\xec\xeb\x04\xd12\r\xa9c}\xfb\xe5\xb1\x10=w\xb2\x17)l\xfe\xad_-\xac\x01>\xbb\x82|\x8e8\xf1SF,\xbb\xbf\x90\x166j\x80\x8e\xec$\x8c\xde"! y\x10G\xe1\x83\xc1\x05C\x03U\xd5\xb5\xa6\xfd\xaa{M\xfb&\xb3\x1d\x93\xc5C\xd4\xb1\xdb9\xd8\xdf\xefv\xf6\xe1\x13*7\x8d\x83:\xdd\xe0X\x99z\x15\'\xd4WD\x01\xe1>\xa3\x89\xa0q\x04\xe72Ah\x04n\x04=E\xd1\x83\xd8\xfbN|\x01"\x06\xed#p\xf1\x19w\xe4\x8aG@&P:#\x01x\x0f\xd0\xab\x17f\x86#\\I\xb9\xa1Q\x00\n\x8d\xd4k\xe22\xc4\x14F\xfeN\t&E\xad0\x07\xa5j\x9a\xaa\xc8\x87\xdc\xc3j\x8f\x11\x91\xb2\x08+^\xc1\x0ey_\xe7Q1\xf2\x82\xf0\x04\x95$\x1f\xf0\xd8\x01\xfa6\xf5B\xd4\xbeB`ej8&=\xca$\xffX\x86\xd8v6\x10;\xfc\x7f\xc4C\xefI\xdc\xf1\xf0\x1c\x1c\x95\x8f\x934\xf2\x955ZCr\xef\xa7\x02\x15\x8c#\x9f\x80\x98\x12\x90\x97\x02\xa2\nS\x0e\x0b8H\x0c\x83\xb5~\xad%\xc1\xc2e\xf7\xccH;\x95k6\xb7\xc2\x01K]\xac\xce\xc2E\x0b\xff`\xd9\xca\xeb\x95ez-\xf26\xa8n\xc3\xe8\x03\xdc\xc64\xc0<Z\xd0|\xb8\x15\xb5\x11\x11kHZ\x9a\xf1\xf1\x85\xec@v\xed+D]\x11t\x02V\x912\xa3\xd1\x08\xd2( \x13\x1a\x91@_!\x1d\x1d\xeb\xb2\xcdxotF\x19\xb9\xf5r\xad\xa5WJv\x1f(\xf2\x81\x87\xa5\xb2\x9c\xd4\xb6\xf3\xf0\x94\x91\x90\xb7Eg\x0e$\xe4D\xe9\x0e\x99\xee\xad\xe45\xd9\x95\xe1\xd3\x8c\xf5U\xb4\x06V\xcee\x1a\xf1\xe9\xe9-\xb2o\xe0\xca\x11p\xec\x9a\xb0\x0f\xd3\xc9\xe6\xaa\xc5x\xa2\x10\xa38\xd5\x93\x05\xcb\x13\xe2\xd3\t\xe6c\x86?\x9b\x82GC\x8d\xa7cz\x95\x95\x19\xd4\xab\x14\xcb\x8a\xa6J\xb3\x19\xb8\x1b\xe5\xafC\xf7\xd7\x18\x86\x9dB\xb9\xc9\x8b\xad\xb1\xfc\xe9\x01\xde*\xa6\x9blh\x05\xea\xdb\xd0\x7f\x17\xe0\xbe\xa1AK\xd1\xddX"[\x81\xf7\xbaW\x96\xa1\xbcQ\xfe\n\x98O*\xf4/\x82\xf3\x89!\x01\x9e\t\xf4\xc7\xba\xe337\x90GyIr\xfd\x15\xcf\xe3\x94\xf9X\xb1\xea\xcb\xd8EX\x91\xa8\x82\xef\rX\xb9\xd4\xc7\xf4\xc7\xffZxi\xe8\xd0\x06\xe5\xcbq\xc0\x8aX/t\xed\x159\xcb\xea\xa7J\xb3\x0c\xe0\xdb\x89^\xdb\xb9\xbf6\xcf\xbf\x18\xb0\x1b\x00\xbd>dz\x81\x88\xef\x0c\xf1\x9b\xc0\xd8\xde\xb6\xe1V\r\xdb\xf5U\xf0\x1cKQP\xbb*S\xc8\x99\x01\xa7\x9c\xe3\x94\xa7,\x9ez\xb2\xa0\xd4\xccI\xd3\xe9\x99]VR\xa3U\r\xb5\xc1\xbd\x0b\xc0\xdd\xd1l\x06qd\xf5\xe4b\xaf\x0fH\xc9\xd7:D]W\x9dR\xb7AD\xee%\x98s[n\xccm\xc5\x90D\x81\xe4g>\xe0\xc7\xb2\xeb\x13\xc4\xaa\x9d\x90\xe1\x91g\xf0\xc1\xc1/\xfe\x07\xf3YE&i\xecu\\\xd5\x15b\xb7\xbaCt83K\x1bP\x96M\x80\xdd\x85\xbe\xd4\xe26\x02D\xde\x9a\x9a\xa0,\x1b\xe06\xa0\xcc\x84Ne\xc9\xd7\x94\xb1\xb6\xd1\xa1\xafd\xfc\x03:\xc3\xfah\xbd\x1d^\xacS\xfe\xc7\xb5\x85\xed\xad\xd9E\xdfXn\x82\xa5\xcdr\x8cVB\x1f\xc6\x85\x9d-\xcd|\x94\xd25\x17\x1b\xbd\xcb\xe2;\xd0o\xc3\xbc\xd3+X\xceu\xbf\xd6Y\xdb\x01rc\x1c\xeb\x9d_\x8b\x8a\xfdB\xb9P\xe5\xc6\x1b\xe5\xfa;\x11\xb2\xc1Pr\xe4(\x1f\x05\t\xf9U\xe9\xe2\r\x7fK\xf2*\xb5$\\\xfd\x0c\xdd\x9ebS\xbf\xf4K\xe3v\xd2\xe4i\x89\xeb\xba\xbbW\xe3\xe1\x9dvu\xa5\n\x1b\xb4s[\x0c\xe9V\xd1Y\xf1\xde\xb0\xa9)\x92ek\x86\xec\x02\xa9\x9fn\xd9\xaa>-\xa3\xd8I\x83\x166\xfc\xf8\xb4\xf6\xac\xb4\xfc?\xd8\x97\x9d\xb081\x7f^\xca\x1d\xf5\x19\x99\xcd\x05EA\xb5\xc1T\xb0`\x7f\xa1\xb7\x9f9\xa0\xad\xb03Mg\x8b\xede\x85\xb3\xa8\xcef\xe3\xd9\xa6\xf4u\x08\xff\xb3yw\xa7@\xdepO\xeb\xa1\xeb3\xe2\xb6U\xf4nX\xd0j\xe4\xba\x15\xedw\x01\xd9\x9b\x98\xb3\xb4qn&\xfdV\xa6\xadM\x9f,\x9b\xb86\x15X1n\rr\xe2\x17\x99\xb5\x06\x8b\x91_=h\x9d\xe7\x7f&\x83\xdck6\xf6\xf3\xf7\xda_Zt\xe7\xff\x02\xcf\x8d\x19\x9b')]) 

# Creating all code files on target project
for f in _context.files:
	file_system.wFile(file_system.get_current_location()+'/'+f.file,zlib.decompress(f.code).decode(),force=True)

    
_architect.Save()
    